@@ -2,11 +2,9 @@
 Author: LetMeFly
 Date: 2022-01-24 15:01:27
 LastEditors: LetMeFly
-LastEditTime: 2022-01-24 15:17:19
+LastEditTime: 2022-01-26 11:00:58
+Description: 获取某场比赛的题面数量
 '''
-"""
-获取某场比赛的题面数量
-"""
 import requests
 from bs4 import BeautifulSoup
 
